# SymphonyVega

A Vega component that displays a list of Vega-Lite specs.
Specs can be provided via the prop `vega_elements`.
If you want to access data from the table, simply provide `"values": "arrow_table"` to the data property of the Vega spec.

## Installation

```bash
pip install symphony_vega
```

## Usage

To learn how to use Symphony, see the [documentation](https://apple.github.io/ml-symphony/).

## Development

To learn about how to build Symphony from source and how to contribute to the framework, please look at [CONTRIBUTING.md](../CONTRIBUTING.md) and the [development documentation](https://apple.github.io/ml-symphony/contributing.html).
